@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
+import functools
 import logging
-import json
 
 from pyramid.events import NewRequest
-from pyramid.response import Response
 from pyramid.settings import asbool
 
-from pyramid_rest.resource import ResourceUtility
+from pyramid_rest.resource import ResourceConfigurator, IResourceConfigurator
 
 log = logging.getLogger(__name__)
 
@@ -35,14 +34,30 @@ def override_request_method(event):
         event.request.method = override
 
 
+def rest_resource_url(request, resource_name, *args):
+    utility = request.registry.getUtility(IResourceConfigurator)
+    return request.host_url + utility.resource_path(resource_name, *args)
+
+
+def rest_resource_path(request, resource_name, *args):
+    utility = request.registry.getUtility(IResourceConfigurator)
+    return utility.resource_path(resource_name, *args)
+
+
 def includeme(config):
     log.info('Including pyramid_rest')
 
-    utility = ResourceUtility()
+    utility = ResourceConfigurator()
 
     config.registry.registerUtility(utility)
 
     config.add_directive('add_resource', utility.add_resource)
+    config.add_directive(
+        'add_singular_resource',
+        functools.partial(utility.add_resource, singular=True),
+        )
+    config.add_request_method(rest_resource_url, 'rest_resource_url')
+    config.add_request_method(rest_resource_path, 'rest_resource_path')
 
     if asbool(config.registry.settings.get('pyramid_rest.tunneling', 'true')):
         config.add_subscriber_predicate(
@@ -56,5 +71,4 @@ def includeme(config):
             request_methods=['POST'],
             )
 
-
     config.commit()
